Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(962)

Unified Diff: media/base/filter_collection.h

Issue 6648004: DemuxerFactory is born! (Closed)
Patch Set: Created 9 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | media/base/filter_collection.cc » ('j') | media/base/mock_filters.h » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: media/base/filter_collection.h
diff --git a/media/base/filter_collection.h b/media/base/filter_collection.h
index c56704fd8e85ca4ba0423be65cd31247a19e38f0..783e79e3f62eac0fc8e762c513df785230887763 100644
--- a/media/base/filter_collection.h
+++ b/media/base/filter_collection.h
@@ -20,13 +20,12 @@ class FilterCollection {
FilterCollection();
~FilterCollection();
// DataSourceFactory accessor methods.
// FilterCollection takes ownership of the factory here.
- void SetDataSourceFactory(DataSourceFactory* factory);
- DataSourceFactory* GetDataSourceFactory();
+ void SetDemuxerFactory(DemuxerFactory* factory);
+ DemuxerFactory* GetDemuxerFactory();
// Adds a filter to the collection.
- void AddDemuxer(Demuxer* filter);
void AddVideoDecoder(VideoDecoder* filter);
void AddAudioDecoder(AudioDecoder* filter);
void AddVideoRenderer(VideoRenderer* filter);
@@ -41,7 +40,6 @@ class FilterCollection {
// Selects a filter of the specified type from the collection.
// If the required filter cannot be found, NULL is returned.
// If a filter is returned it is removed from the collection.
- void SelectDemuxer(scoped_refptr<Demuxer>* filter_out);
void SelectVideoDecoder(scoped_refptr<VideoDecoder>* filter_out);
void SelectAudioDecoder(scoped_refptr<AudioDecoder>* filter_out);
void SelectVideoRenderer(scoped_refptr<VideoRenderer>* filter_out);
@@ -52,7 +50,6 @@ class FilterCollection {
// the following types. This is used to mark, identify, and support
// downcasting of different filter types stored in the filters_ list.
enum FilterType {
- DEMUXER,
AUDIO_DECODER,
VIDEO_DECODER,
AUDIO_RENDERER,
@@ -63,7 +60,7 @@ class FilterCollection {
typedef std::pair<FilterType, scoped_refptr<Filter> > FilterListElement;
typedef std::list<FilterListElement> FilterList;
FilterList filters_;
- scoped_ptr<DataSourceFactory> data_source_factory_;
+ scoped_ptr<DemuxerFactory> demuxer_factory_;
// Helper function that adds a filter to the filter list.
void AddFilter(FilterType filter_type, Filter* filter);
« no previous file with comments | « no previous file | media/base/filter_collection.cc » ('j') | media/base/mock_filters.h » ('J')
@@ -20,13 +20,12 @@ class FilterCollection {
FilterCollection();
~FilterCollection();
- // DataSourceFactory accessor methods.
+ // DemuxerFactory accessor methods.
// FilterCollection takes ownership of the factory here.

Powered by Google App Engine
This is Rietveld 408576698